==> alibabacloud_paistudio20220112-2.1.9.tar.gz: alibabacloud_paistudio20220112-2.1.9/ChangeLog.md <==
2025-08-06 Version: 2.1.8
- Update API ListNodes: add request parameters PaymentType.


2025-07-25 Version: 2.1.7
- Update API ListQuotas: add request parameters HasResource.
- Update API ListResourceGroups: add request parameters HasResource.


2025-06-30 Version: 2.1.6
- Update API ListResourceGroups: add request parameters ResourceGroupIDs.


2025-06-30 Version: 2.1.6
- Update API ListResourceGroups: add request parameters ResourceGroupIDs.


2025-06-18 Version: 2.1.5
- Update API ListNodes: add request parameters AvailabilityZone.
- Update API ListNodes: add request parameters HyperZone.


2025-04-16 Version: 2.1.4
- Update API ListNodes: add request parameters ReasonCodes.


2025-03-19 Version: 2.1.3
- Update API ListNodes: add param MachineGroupIds.
- Update API ListResourceGroupMachineGroups: add param MachineGroupIDs.


2025-02-19 Version: 2.1.2
- Update API ListQuotaWorkloads: add param WithHistoricalData.


2024-12-30 Version: 2.1.0
- Support API GetSpotPriceHistory.


2024-12-17 Version: 2.0.2
- Generated python 2022-01-12 for PaiStudio.

2024-12-16 Version: 2.0.1
- Update API ListTrainingJobs: update response param.


2024-12-10 Version: 2.0.0
- Support API ListQuotaWorkloads.
- Update API CreateTrainingJob: update param body.
- Update API DeleteAlgorithmVersion: update param AlgorithmId.
- Update API DeleteAlgorithmVersion: update param AlgorithmVersion.
- Update API GetTrainingJob: update response param.
- Update API ListTrainingJobMetrics: update response param.
- Update API ListTrainingJobs: update response param.


2024-08-30 Version: 1.2.0
- Support API CheckInstanceWebTerminal.
- Support API CreateInstanceWebTerminal.
- Support API DeleteAlgorithm.
- Support API DeleteAlgorithmVersion.
- Support API DeleteTrainingJob.
- Support API DeleteTrainingJobLabels.
- Support API GetToken.
- Support API GetTrainingJobErrorInfo.
- Support API GetTrainingJobLatestMetrics.
- Support API ListNodes.
- Support API ListTrainingJobEvents.
- Support API ListTrainingJobInstanceEvents.
- Support API ListTrainingJobInstanceMetrics.
- Support API ListTrainingJobOutputModels.
- Update API CreateTrainingJob: update param body.
- Update API GetMachineGroup: update response param.
- Update API GetQuota: add param Verbose.
- Update API GetTrainingJob: update response param.
- Update API ListQuotas: add param Verbose.
- Update API ListQuotas: add param WorkspaceName.
- Update API ListQuotas: update response param.
- Update API ListResourceGroupMachineGroups: add param OrderInstanceId.
- Update API ListTrainingJobs: update response param.
- Update API UpdateQuota: update param body.


2024-03-19 Version: 1.1.6
- Update API ListQuotas: update response param.


2024-03-14 Version: 1.1.5
- Update API CreateTrainingJob: update param body.
- Update API GetTrainingJob: update response param.
- Update API ListTrainingJobs: update response param.


2024-02-29 Version: 1.1.4
- Update API CreateTrainingJob: update param body.
- Update API GetTrainingJob: update response param.
- Update API ListTrainingJobs: update response param.


2024-01-24 Version: 1.1.3
- Generated python 2022-01-12 for PaiStudio.

2023-12-15 Version: 1.1.2
- Generated python 2022-01-12 for PaiStudio.

2023-12-07 Version: 1.1.1
- Generated python 2022-01-12 for PaiStudio.

2023-11-23 Version: 1.1.0
- Generated python 2022-01-12 for PaiStudio.

2023-09-06 Version: 1.0.12
- Generated python 2022-01-12 for PaiStudio.

2023-09-01 Version: 1.0.11
- Generated python 2022-01-12 for PaiStudio.

2023-08-01 Version: 1.0.10
- Update AlgorithmSpec.

2022-11-14 Version: 1.0.9
- Resource Service sdk .

2022-09-26 Version: 1.0.8
- Resource Service python sdk .

2022-09-24 Version: 1.0.7
- Resource Service python sdk .

2022-09-09 Version: 1.0.6
- Resource Service python sdk .

2022-09-02 Version: 1.0.5
- Resource Service python sdk .

2022-08-29 Version: 1.0.2
- Resource Service python sdk .

2022-08-29 Version: 1.0.1
- Resource Service go sdk .

2022-08-26 Version: 1.0.0
- Resource Service go sdk .

==> alibabacloud_paistudio20220112-2.1.16.tar.gz: alibabacloud_paistudio20220112-2.1.16/ChangeLog.md <==
2025-11-07 Version: 2.1.15
- Generated python 2022-01-12 for PaiStudio.

2025-11-06 Version: 2.1.14
- Update API CreateQuota: add request parameters body.ClusterSpec.
- Update API GetQuota: add response parameters Body.QuotaCluster.
- Update API ListQuotas: add request parameters ClusterType.


2025-11-06 Version: 2.1.14
- Update API CreateQuota: add request parameters body.ClusterSpec.
- Update API GetQuota: add response parameters Body.QuotaCluster.
- Update API ListQuotas: add request parameters ClusterType.


2025-11-04 Version: 2.1.13
- Update API ListNodes: add request parameters WorkspaceId.


2025-10-31 Version: 2.1.12
- Generated python 2022-01-12 for PaiStudio.

2025-10-30 Version: 2.1.11
- Generated python 2022-01-12 for PaiStudio.

2025-10-13 Version: 2.1.10
- Update API CreateResourceGroup: add request parameters body.Version.
- Update API GetQuota: add response parameters Body.HyperZones.
- Update API GetQuota: add response parameters Body.Version.
- Update API GetResourceGroup: add response parameters Body.Version.
- Update API ListNodes: add request parameters CliqueID.
- Update API ListNodes: add request parameters HyperNode.
- Update API ListNodes: add request parameters OrderInstanceIds.
- Update API ListQuotas: add request parameters Versions.
- Update API ListResourceGroups: add request parameters Versions.


2025-08-22 Version: 2.1.9
- Update API GetResourceGroupMachineGroup: add response parameters Body.AllocatableCpu.
- Update API GetResourceGroupMachineGroup: add response parameters Body.AllocatableMemory.
- Update API GetResourceGroupMachineGroup: add response parameters Body.SystemReservedCpu.
- Update API GetResourceGroupMachineGroup: add response parameters Body.SystemReservedMemory.


2025-08-06 Version: 2.1.8
- Update API ListNodes: add request parameters PaymentType.


2025-07-25 Version: 2.1.7
- Update API ListQuotas: add request parameters HasResource.
- Update API ListResourceGroups: add request parameters HasResource.


2025-06-30 Version: 2.1.6
- Update API ListResourceGroups: add request parameters ResourceGroupIDs.


2025-06-30 Version: 2.1.6
- Update API ListResourceGroups: add request parameters ResourceGroupIDs.


2025-06-18 Version: 2.1.5
- Update API ListNodes: add request parameters AvailabilityZone.
- Update API ListNodes: add request parameters HyperZone.


2025-04-16 Version: 2.1.4
- Update API ListNodes: add request parameters ReasonCodes.


2025-03-19 Version: 2.1.3
- Update API ListNodes: add param MachineGroupIds.
- Update API ListResourceGroupMachineGroups: add param MachineGroupIDs.


2025-02-19 Version: 2.1.2
- Update API ListQuotaWorkloads: add param WithHistoricalData.


2024-12-30 Version: 2.1.0
- Support API GetSpotPriceHistory.


2024-12-17 Version: 2.0.2
- Generated python 2022-01-12 for PaiStudio.

2024-12-16 Version: 2.0.1
- Update API ListTrainingJobs: update response param.


2024-12-10 Version: 2.0.0
- Support API ListQuotaWorkloads.
- Update API CreateTrainingJob: update param body.
- Update API DeleteAlgorithmVersion: update param AlgorithmId.
- Update API DeleteAlgorithmVersion: update param AlgorithmVersion.
- Update API GetTrainingJob: update response param.
- Update API ListTrainingJobMetrics: update response param.
- Update API ListTrainingJobs: update response param.


2024-08-30 Version: 1.2.0
- Support API CheckInstanceWebTerminal.
- Support API CreateInstanceWebTerminal.
- Support API DeleteAlgorithm.
- Support API DeleteAlgorithmVersion.
- Support API DeleteTrainingJob.
- Support API DeleteTrainingJobLabels.
- Support API GetToken.
- Support API GetTrainingJobErrorInfo.
- Support API GetTrainingJobLatestMetrics.
- Support API ListNodes.
- Support API ListTrainingJobEvents.
- Support API ListTrainingJobInstanceEvents.
- Support API ListTrainingJobInstanceMetrics.
- Support API ListTrainingJobOutputModels.
- Update API CreateTrainingJob: update param body.
- Update API GetMachineGroup: update response param.
- Update API GetQuota: add param Verbose.
- Update API GetTrainingJob: update response param.
- Update API ListQuotas: add param Verbose.
- Update API ListQuotas: add param WorkspaceName.
- Update API ListQuotas: update response param.
- Update API ListResourceGroupMachineGroups: add param OrderInstanceId.
- Update API ListTrainingJobs: update response param.
- Update API UpdateQuota: update param body.


2024-03-19 Version: 1.1.6
- Update API ListQuotas: update response param.


2024-03-14 Version: 1.1.5
- Update API CreateTrainingJob: update param body.
- Update API GetTrainingJob: update response param.
- Update API ListTrainingJobs: update response param.


2024-02-29 Version: 1.1.4
- Update API CreateTrainingJob: update param body.
- Update API GetTrainingJob: update response param.
- Update API ListTrainingJobs: update response param.


2024-01-24 Version: 1.1.3
- Generated python 2022-01-12 for PaiStudio.

2023-12-15 Version: 1.1.2
- Generated python 2022-01-12 for PaiStudio.

2023-12-07 Version: 1.1.1
- Generated python 2022-01-12 for PaiStudio.

2023-11-23 Version: 1.1.0
- Generated python 2022-01-12 for PaiStudio.

2023-09-06 Version: 1.0.12
- Generated python 2022-01-12 for PaiStudio.

2023-09-01 Version: 1.0.11
- Generated python 2022-01-12 for PaiStudio.

2023-08-01 Version: 1.0.10
- Update AlgorithmSpec.

2022-11-14 Version: 1.0.9
- Resource Service sdk .

2022-09-26 Version: 1.0.8
- Resource Service python sdk .

2022-09-24 Version: 1.0.7
- Resource Service python sdk .

2022-09-09 Version: 1.0.6
- Resource Service python sdk .

2022-09-02 Version: 1.0.5
- Resource Service python sdk .

2022-08-29 Version: 1.0.2
- Resource Service python sdk .

2022-08-29 Version: 1.0.1
- Resource Service go sdk .

2022-08-26 Version: 1.0.0
- Resource Service go sdk .
